Documentation
¶
Overview ¶
An OpenGL user interface library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Element ¶
type Element struct {
// Click is the channel to communicate on onClick, or nil if not clickable.
Click chan int
// Should this be rendered with an opaque backing rectangle?
Pane bool
// Will this be an OpenGL FBO? (Likely to be a 4:3 square.)
RSquare bool
// Text to display, or nil.
Text string
// Is this an X or a v button or something?
Small bool
}
type HContainer ¶
type HContainer struct {
Container
}
type WContainer ¶
type WContainer struct {
Container
}
Click to show internal directories.
Click to hide internal directories.